@@ -26,6 +26,7 @@ import (
 
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	bootstrapapi "k8s.io/cluster-bootstrap/token/api"
 )
 
 func TestMarshalJSON(t *testing.T) {
@@ -275,7 +276,7 @@ func TestBootstrapTokenToSecret(t *testing.T) {
 					Name:      "bootstrap-token-abcdef",
 					Namespace: "kube-system",
 				},
-				Type: v1.SecretType("bootstrap.kubernetes.io/token"),
+				Type: bootstrapapi.SecretTypeBootstrapToken,
 				Data: map[string][]byte{
 					"token-id":                       []byte("abcdef"),
 					"token-secret":                   []byte("abcdef0123456789"),
@@ -648,7 +649,7 @@ func TestBootstrapTokenFromSecret(t *testing.T) {
 					Name:      rt.name,
 					Namespace: "kube-system",
 				},
-				Type: v1.SecretType("bootstrap.kubernetes.io/token"),
+				Type: bootstrapapi.SecretTypeBootstrapToken,
 				Data: rt.data,
 			})
 			if (err != nil) != rt.expectedError {
