@@ -145,4 +145,13 @@ const (
 
 	// AllowExperimentalAPI flag can be used to allow experimental / work in progress APIs
 	AllowExperimentalAPI = "allow-experimental-api"
+
+	// AllowRCUpgrades enable this flag will allow upgrading to a release candidate version of Kubernetes.
+	AllowRCUpgrades = "allow-release-candidate-upgrades"
+
+	// AllowExperimentalUpgrades enable this flag will allow upgrading to an alpha/beta/release candidate version of Kubernetes.
+	AllowExperimentalUpgrades = "allow-experimental-upgrades"
+
+	// PrintConfig specifies whether the cluster configuration that will be used in the upgrade should be printed or not.
+	PrintConfig = "print-config"
 )
