@@ -34,10 +34,7 @@ var PluginsV1 = &config.Plugins{
 			{Name: names.NodePorts},
 			{Name: names.NodeResourcesFit, Weight: 1},
 			{Name: names.VolumeRestrictions},
-			{Name: names.EBSLimits},
-			{Name: names.GCEPDLimits},
 			{Name: names.NodeVolumeLimits},
-			{Name: names.AzureDiskLimits},
 			{Name: names.VolumeBinding},
 			{Name: names.VolumeZone},
 			{Name: names.PodTopologySpread, Weight: 2},
@@ -68,10 +65,7 @@ var ExpandedPluginsV1 = &config.Plugins{
 			{Name: names.NodePorts},
 			{Name: names.NodeResourcesFit},
 			{Name: names.VolumeRestrictions},
-			{Name: names.EBSLimits},
-			{Name: names.GCEPDLimits},
 			{Name: names.NodeVolumeLimits},
-			{Name: names.AzureDiskLimits},
 			{Name: names.VolumeBinding},
 			{Name: names.VolumeZone},
 			{Name: names.PodTopologySpread},
@@ -87,10 +81,7 @@ var ExpandedPluginsV1 = &config.Plugins{
 			{Name: names.NodePorts},
 			{Name: names.NodeResourcesFit},
 			{Name: names.VolumeRestrictions},
-			{Name: names.EBSLimits},
-			{Name: names.GCEPDLimits},
 			{Name: names.NodeVolumeLimits},
-			{Name: names.AzureDiskLimits},
 			{Name: names.VolumeBinding},
 			{Name: names.VolumeZone},
 			{Name: names.PodTopologySpread},
