@@ -28,6 +28,7 @@ import (
 
 	apiequality "k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
+	"k8s.io/apimachinery/pkg/api/meta"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/fields"
 	"k8s.io/apimachinery/pkg/labels"
@@ -1236,6 +1237,7 @@ func RunSendInitialEventsBackwardCompatibility(ctx context.Context, t *testing.T
 // - false indicates the value of the param was set to "false" by a test case
 // - true  indicates the value of the param was set to "true" by a test case
 func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interface) {
+	featuregatetesting.SetFeatureGateDuringTest(t, utilfeature.DefaultFeatureGate, features.WatchList, true)
 	trueVal, falseVal := true, false
 	addEventsFromCreatedPods := func(createdInitialPods []*example.Pod) []watch.Event {
 		var ret []watch.Event
@@ -1244,16 +1246,16 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 		}
 		return ret
 	}
-	initialEventsEndFromLastCreatedPod := func(createdInitialPods []*example.Pod) []watch.Event {
-		return []watch.Event{{
+	initialEventsEndFromLastCreatedPod := func(createdInitialPods []*example.Pod) watch.Event {
+		return watch.Event{
 			Type: watch.Bookmark,
 			Object: &example.Pod{
 				ObjectMeta: metav1.ObjectMeta{
 					ResourceVersion: createdInitialPods[len(createdInitialPods)-1].ResourceVersion,
-					Annotations:     map[string]string{"k8s.io/initial-events-end": "true"},
+					Annotations:     map[string]string{metav1.InitialEventsAnnotationKey: "true"},
 				},
 			},
-		}}
+		}
 	}
 	scenarios := []struct {
 		name                string
@@ -1267,19 +1269,19 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 		initialPods                []*example.Pod
 		podsAfterEstablishingWatch []*example.Pod
 
-		expectedInitialEvents                func(createdInitialPods []*example.Pod) []watch.Event
-		expectedInitialEventsBookmark        func(createdInitialPods []*example.Pod) []watch.Event
-		expectedEventsAfterEstablishingWatch func(createdPodsAfterWatch []*example.Pod) []watch.Event
+		expectedInitialEvents                      func(createdInitialPods []*example.Pod) []watch.Event
+		expectedInitialEventsBookmarkWithMinimalRV func(createdInitialPods []*example.Pod) watch.Event
+		expectedEventsAfterEstablishingWatch       func(createdPodsAfterWatch []*example.Pod) []watch.Event
 	}{
 		{
-			name:                                 "allowWatchBookmarks=true, sendInitialEvents=true, RV=unset",
-			allowWatchBookmarks:                  true,
-			sendInitialEvents:                    &trueVal,
-			initialPods:                          []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
-			expectedInitialEvents:                addEventsFromCreatedPods,
-			expectedInitialEventsBookmark:        initialEventsEndFromLastCreatedPod,
-			podsAfterEstablishingWatch:           []*example.Pod{makePod("4"), makePod("5")},
-			expectedEventsAfterEstablishingWatch: addEventsFromCreatedPods,
+			name:                  "allowWatchBookmarks=true, sendInitialEvents=true, RV=unset",
+			allowWatchBookmarks:   true,
+			sendInitialEvents:     &trueVal,
+			initialPods:           []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
+			expectedInitialEvents: addEventsFromCreatedPods,
+			expectedInitialEventsBookmarkWithMinimalRV: initialEventsEndFromLastCreatedPod,
+			podsAfterEstablishingWatch:                 []*example.Pod{makePod("4"), makePod("5")},
+			expectedEventsAfterEstablishingWatch:       addEventsFromCreatedPods,
 		},
 		{
 			name:                                 "allowWatchBookmarks=true, sendInitialEvents=false, RV=unset",
@@ -1306,15 +1308,15 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 		},
 
 		{
-			name:                                 "allowWatchBookmarks=true, sendInitialEvents=true, RV=0",
-			allowWatchBookmarks:                  true,
-			sendInitialEvents:                    &trueVal,
-			resourceVersion:                      "0",
-			initialPods:                          []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
-			expectedInitialEvents:                addEventsFromCreatedPods,
-			expectedInitialEventsBookmark:        initialEventsEndFromLastCreatedPod,
-			podsAfterEstablishingWatch:           []*example.Pod{makePod("4"), makePod("5")},
-			expectedEventsAfterEstablishingWatch: addEventsFromCreatedPods,
+			name:                  "allowWatchBookmarks=true, sendInitialEvents=true, RV=0",
+			allowWatchBookmarks:   true,
+			sendInitialEvents:     &trueVal,
+			resourceVersion:       "0",
+			initialPods:           []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
+			expectedInitialEvents: addEventsFromCreatedPods,
+			expectedInitialEventsBookmarkWithMinimalRV: initialEventsEndFromLastCreatedPod,
+			podsAfterEstablishingWatch:                 []*example.Pod{makePod("4"), makePod("5")},
+			expectedEventsAfterEstablishingWatch:       addEventsFromCreatedPods,
 		},
 		{
 			name:                                 "allowWatchBookmarks=true, sendInitialEvents=false, RV=0",
@@ -1344,15 +1346,15 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 		},
 
 		{
-			name:                                 "allowWatchBookmarks=true, sendInitialEvents=true, RV=1",
-			allowWatchBookmarks:                  true,
-			sendInitialEvents:                    &trueVal,
-			resourceVersion:                      "1",
-			initialPods:                          []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
-			expectedInitialEvents:                addEventsFromCreatedPods,
-			expectedInitialEventsBookmark:        initialEventsEndFromLastCreatedPod,
-			podsAfterEstablishingWatch:           []*example.Pod{makePod("4"), makePod("5")},
-			expectedEventsAfterEstablishingWatch: addEventsFromCreatedPods,
+			name:                  "allowWatchBookmarks=true, sendInitialEvents=true, RV=1",
+			allowWatchBookmarks:   true,
+			sendInitialEvents:     &trueVal,
+			resourceVersion:       "1",
+			initialPods:           []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
+			expectedInitialEvents: addEventsFromCreatedPods,
+			expectedInitialEventsBookmarkWithMinimalRV: initialEventsEndFromLastCreatedPod,
+			podsAfterEstablishingWatch:                 []*example.Pod{makePod("4"), makePod("5")},
+			expectedEventsAfterEstablishingWatch:       addEventsFromCreatedPods,
 		},
 		{
 			name:                                 "allowWatchBookmarks=true, sendInitialEvents=false, RV=1",
@@ -1384,15 +1386,15 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 		},
 
 		{
-			name:                                 "allowWatchBookmarks=true, sendInitialEvents=true, RV=useCurrentRV",
-			allowWatchBookmarks:                  true,
-			sendInitialEvents:                    &trueVal,
-			useCurrentRV:                         true,
-			initialPods:                          []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
-			expectedInitialEvents:                addEventsFromCreatedPods,
-			expectedInitialEventsBookmark:        initialEventsEndFromLastCreatedPod,
-			podsAfterEstablishingWatch:           []*example.Pod{makePod("4"), makePod("5")},
-			expectedEventsAfterEstablishingWatch: addEventsFromCreatedPods,
+			name:                  "allowWatchBookmarks=true, sendInitialEvents=true, RV=useCurrentRV",
+			allowWatchBookmarks:   true,
+			sendInitialEvents:     &trueVal,
+			useCurrentRV:          true,
+			initialPods:           []*example.Pod{makePod("1"), makePod("2"), makePod("3")},
+			expectedInitialEvents: addEventsFromCreatedPods,
+			expectedInitialEventsBookmarkWithMinimalRV: initialEventsEndFromLastCreatedPod,
+			podsAfterEstablishingWatch:                 []*example.Pod{makePod("4"), makePod("5")},
+			expectedEventsAfterEstablishingWatch:       addEventsFromCreatedPods,
 		},
 		{
 			name:                                 "allowWatchBookmarks=true, sendInitialEvents=false, RV=useCurrentRV",
@@ -1439,14 +1441,11 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 	}
 	for idx, scenario := range scenarios {
 		t.Run(scenario.name, func(t *testing.T) {
+			t.Parallel()
 			// set up env
-			defer featuregatetesting.SetFeatureGateDuringTest(t, utilfeature.DefaultFeatureGate, features.WatchList, true)()
 			if scenario.expectedInitialEvents == nil {
 				scenario.expectedInitialEvents = func(_ []*example.Pod) []watch.Event { return nil }
 			}
-			if scenario.expectedInitialEventsBookmark == nil {
-				scenario.expectedInitialEventsBookmark = func(_ []*example.Pod) []watch.Event { return nil }
-			}
 			if scenario.expectedEventsAfterEstablishingWatch == nil {
 				scenario.expectedEventsAfterEstablishingWatch = func(_ []*example.Pod) []watch.Event { return nil }
 			}
@@ -1480,7 +1479,29 @@ func RunWatchSemantics(ctx context.Context, t *testing.T, store storage.Interfac
 
 			// make sure we only get initial events
 			testCheckResultsInStrictOrder(t, w, scenario.expectedInitialEvents(createdPods))
-			testCheckResultsInStrictOrder(t, w, scenario.expectedInitialEventsBookmark(createdPods))
+
+			// make sure that the actual bookmark has at least RV >= to the expected one
+			if scenario.expectedInitialEventsBookmarkWithMinimalRV != nil {
+				testCheckResultFunc(t, w, func(actualEvent watch.Event) {
+					expectedBookmarkEventWithMinRV := scenario.expectedInitialEventsBookmarkWithMinimalRV(createdPods)
+					expectedObj, err := meta.Accessor(expectedBookmarkEventWithMinRV.Object)
+					require.NoError(t, err)
+					expectedRV, err := storage.APIObjectVersioner{}.ObjectResourceVersion(expectedBookmarkEventWithMinRV.Object)
+					require.NoError(t, err)
+
+					actualObj, err := meta.Accessor(actualEvent.Object)
+					require.NoError(t, err)
+					actualRV, err := storage.APIObjectVersioner{}.ObjectResourceVersion(actualEvent.Object)
+					require.NoError(t, err)
+
+					require.GreaterOrEqual(t, actualRV, expectedRV)
+
+					// once we know that the RV is at least >= the expected one
+					// rewrite it so that we can compare the objs
+					expectedObj.SetResourceVersion(actualObj.GetResourceVersion())
+					expectNoDiff(t, "incorrect event", expectedBookmarkEventWithMinRV, actualEvent)
+				})
+			}
 
 			createdPods = []*example.Pod{}
 			// add a pod that is greater than the storage's RV when the watch was started
@@ -1512,12 +1533,12 @@ func RunWatchSemanticInitialEventsExtended(ctx context.Context, t *testing.T, st
 		watchEvents = append(watchEvents, watch.Event{Type: watch.Bookmark, Object: &example.Pod{
 			ObjectMeta: metav1.ObjectMeta{
 				ResourceVersion: globalResourceVersion,
-				Annotations:     map[string]string{"k8s.io/initial-events-end": "true"},
+				Annotations:     map[string]string{metav1.InitialEventsAnnotationKey: "true"},
 			},
 		}})
 		return watchEvents
 	}
-	defer featuregatetesting.SetFeatureGateDuringTest(t, utilfeature.DefaultFeatureGate, features.WatchList, true)()
+	featuregatetesting.SetFeatureGateDuringTest(t, utilfeature.DefaultFeatureGate, features.WatchList, true)
 
 	initialPods := []*example.Pod{}
 	ns := "ns-foo"
@@ -1550,73 +1571,6 @@ func RunWatchSemanticInitialEventsExtended(ctx context.Context, t *testing.T, st
 	testCheckNoMoreResults(t, w)
 }
 
-func RunWatchErrorIsBlockingFurtherEvents(ctx context.Context, t *testing.T, store InterfaceWithPrefixTransformer) {
-	foo := &example.Pod{ObjectMeta: metav1.ObjectMeta{Namespace: "test", Name: "foo"}}
-	fooKey := fmt.Sprintf("/pods/%s/%s", foo.Namespace, foo.Name)
-	fooCreated := &example.Pod{}
-	if err := store.Create(context.Background(), fooKey, foo, fooCreated, 0); err != nil {
-		t.Errorf("failed to create object: %v", err)
-	}
-	bar := &example.Pod{ObjectMeta: metav1.ObjectMeta{Namespace: "test", Name: "bar"}}
-	barKey := fmt.Sprintf("/pods/%s/%s", bar.Namespace, bar.Name)
-	barCreated := &example.Pod{}
-	if err := store.Create(context.Background(), barKey, bar, barCreated, 0); err != nil {
-		t.Errorf("failed to create object: %v", err)
-	}
-
-	// Update transformer to ensure that foo will become effectively corrupted.
-	revertTransformer := store.UpdatePrefixTransformer(
-		func(transformer *PrefixTransformer) value.Transformer {
-			transformer.prefix = []byte("other-prefix")
-			return transformer
-		})
-	defer revertTransformer()
-
-	baz := &example.Pod{ObjectMeta: metav1.ObjectMeta{Namespace: "test", Name: "baz"}}
-	bazKey := fmt.Sprintf("/pods/%s/%s", baz.Namespace, baz.Name)
-	bazCreated := &example.Pod{}
-	if err := store.Create(context.Background(), bazKey, baz, bazCreated, 0); err != nil {
-		t.Errorf("failed to create object: %v", err)
-	}
-
-	opts := storage.ListOptions{
-		ResourceVersion: fooCreated.ResourceVersion,
-		Predicate:       storage.Everything,
-		Recursive:       true,
-	}
-
-	// Run N concurrent watches. Given the asynchronous nature, we increase the
-	// probability of hitting the race in at least one of those watches.
-	concurrentWatches := 10
-	wg := sync.WaitGroup{}
-	for i := 0; i < concurrentWatches; i++ {
-		wg.Add(1)
-		go func() {
-			defer wg.Done()
-			w, err := store.Watch(ctx, "/pods", opts)
-			if err != nil {
-				t.Errorf("failed to create watch: %v", err)
-				return
-			}
-
-			// We issue the watch starting from object bar.
-			// The object fails TransformFromStorage and generates ERROR watch event.
-			// The further events (i.e. ADDED event for baz object) should not be
-			// emitted, so we verify no events other than ERROR type are emitted.
-			for {
-				event, ok := <-w.ResultChan()
-				if !ok {
-					break
-				}
-				if event.Type != watch.Error {
-					t.Errorf("unexpected event: %#v", event)
-				}
-			}
-		}()
-	}
-	wg.Wait()
-}
-
 func makePod(namePrefix string) *example.Pod {
 	return &example.Pod{
 		ObjectMeta: metav1.ObjectMeta{
