@@ -309,9 +309,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "POST /api/v1/nodes",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
@@ -428,9 +428,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "GET /api/v1/nodes/{:name}",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
@@ -518,9 +518,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "GET /api/v1/nodes",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
@@ -562,38 +562,6 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 						"Writing http response done",
 					},
 				},
-				{
-					name: "List(recursive=true) etcd3",
-					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"audit-id": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() != ""
-						},
-						"key": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() == "/minions"
-						},
-						"resourceVersion": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() == ""
-						},
-						"resourceVersionMatch": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() == ""
-						},
-						"limit": func(v *commonv1.AnyValue) bool {
-							return v.GetIntValue() == 0
-						},
-						"continue": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() == ""
-						},
-					},
-				},
-				{
-					name: "etcdserverpb.KV/Range",
-					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"rpc.system": func(v *commonv1.AnyValue) bool {
-							return v.GetStringValue() == "grpc"
-						},
-					},
-					events: []string{"message"},
-				},
 				{
 					name: "SerializeObject",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
@@ -636,9 +604,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "PUT /api/v1/nodes/{:name}",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
@@ -780,9 +748,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "PATCH /api/v1/nodes/{:name}",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
@@ -901,9 +869,9 @@ endpoint: %s`, listener.Addr().String())), os.FileMode(0755)); err != nil {
 			},
 			expectedTrace: []*spanExpectation{
 				{
-					name: "KubernetesAPI",
+					name: "DELETE /api/v1/nodes/{:name}",
 					attributes: map[string]func(*commonv1.AnyValue) bool{
-						"http.user_agent": func(v *commonv1.AnyValue) bool {
+						"user_agent.original": func(v *commonv1.AnyValue) bool {
 							return strings.HasPrefix(v.GetStringValue(), "tracing.test")
 						},
 						"http.target": func(v *commonv1.AnyValue) bool {
